﻿local MorgBid2 = LibStub("AceAddon-3.0"):GetAddon("MorgBid2")
local MorgBid2_Options = LibStub("AceAddon-3.0"):NewAddon("MorgBid2_Options")
local C = LibStub("AceConfigDialog-3.0")
local L = LibStub("AceLocale-3.0"):GetLocale("MorgBid2_Options")
local GrowDirections = {L["LEFT"], L["RIGHT"], L["UP"], L["DOWN"]}
local db = MorgBid2.db.profile

local options = {
		type = "group",
		handler = MorgBid2_Options,
		name = L["MorgBid2"],
		desc = L["MorgBid2"],
		args = {
			options = {
			name = L["Options"],
			handler = MorgBid2_Options,
			type = "group",
			args = {
				head = {
					type = "header",
					name = L["General options"] .. " " .. MorgBid2.versionstring,
					order = 10
				},
				showhints = {
					type = "toggle",
					name = L["Hide hints"],
					desc = L["Disables the tooltip hints."],
					get = function() return MorgBid2.db.profile.hints end,
					set = function(info, v) MorgBid2.db.profile.hints = v end,
					order = 20
				},
				resulttt = {
					type = "toggle",
					name = L["Use result tooltip"],
					desc = L["Shows the DKP listing of the current item after the auction ends."],
					get = function() return MorgBid2.db.profile.result end,
					set = function(info, v) MorgBid2.db.profile.result = v end,
					order = 30
				},
				alwaysresulttt = {
					type = "toggle",
					name = L["Show ALL results"],
					desc = L["Shows the result tooltip even if you are NOT included in the auction."],
					get = function() return MorgBid2.db.profile.alwaysresult end,
					set = function(info, v) MorgBid2.db.profile.alwaysresult = v end,
					order = 33
				},
				devmode = {
					type = "toggle",
					name = L["Developer mode"],
					desc = L["Developer mode"],
					get = function() return MorgBid2.db.profile.devmode end,
					set = function(info, v) MorgBid2.db.profile.devmode = v end,
					order = 35
				},
				reset = {
					type = "execute",
					name = L["Reset frames"],
					desc = L["Reset default frame positions."],
					func = "ResetFrames",
					order = 40
				},
				head1 = {
					type = "header",
					name = L["All frames"],
					order = 100
				},
				background = {
					type = "select",
					dialogControl = "LSM30_Background",
					name = L["Background texture"],
					desc = L["Background texture"],
					get = function() return MorgBid2.db.profile.media.background end,
					set = function(info, v) 
							MorgBid2.db.profile.media.background = v
							MorgBid2:UpdateFrameMedia()
						end,
					values = AceGUIWidgetLSMlists.background, 
					order = 110
				},
				border = {
					type = "select",
					dialogControl = "LSM30_Border",
					name = L["Border texture"],
					desc = L["Border texture"],
					get = function() return MorgBid2.db.profile.media.border end,
					set = function(info, v) 
							MorgBid2.db.profile.media.border = v
							MorgBid2:UpdateFrameMedia()
						end,
					values = AceGUIWidgetLSMlists.border, 
					order = 120
				},
				space = {
					type = "description",
					name = "",
					order = 125
				},
				backdropC = {
					type = "color",
					name = L["Background color"],
					hasAlpha = true,
					set = "SetColorOpt",
					get = "GetColorOpt",
					order = 130
				},
				borderC = {
					type = "color",
					name = L["Border color"],
					hasAlpha = true,
					set = "SetColorOpt",
					get = "GetColorOpt",
					order = 140
				},
				head2 = {
					type = "header",
					name = L["Bidding tooltip options"],
					order = 200
				},
				font = {
			 		type = "select",
			 		dialogControl = "LSM30_Font",
			 		name = L["Font"],
			 		desc = L["Font"],
			 		get = function() return MorgBid2.db.profile.media.font end,
			 		set = function(info, v) MorgBid2.db.profile.media.font = v MorgBid2:UpdateFrameMedia() end,
			 		values = AceGUIWidgetLSMlists.font, 
					order = 210
				},
				fontsize = {
					type = "range",
					name = L["Font size"],
					get = function() return MorgBid2.db.profile.media.fontsize end,
					set = function(info, v) MorgBid2.db.profile.media.fontsize = v MorgBid2:UpdateFrameMedia() end,
					min = 1, 
					max = 30, 
					step = 1,
					order = 220
				},
				head3 = {
					type = "header",
					name = L["Result Frame options"],
					hidden = function() return not MorgBid2.db.profile.result end,
					order = 300
				},
				autoclose = {
					type = "toggle",
					name = L["Autoclose results"],
					desc = L["Automatically close results frame after auction ends."],
					get = function() return MorgBid2.db.profile.autoclose end,
					set = function(info, v) MorgBid2.db.profile.autoclose = v end,
					hidden = function() return not MorgBid2.db.profile.result end,
					order = 310
				},
				lockdown = {
					type = "toggle",
					name = L["Combat lockdown"],
					desc = L["Disables result frames while in combat."],
					get = function() return MorgBid2.db.profile.lockdown end,
					set = function(info, v) MorgBid2.db.profile.lockdown = v end,
					hidden = function() return not MorgBid2.db.profile.result end,
					order = 315
				},
				head4 = {
					type = "description",
					name = "",
					hidden = function() return not MorgBid2.db.profile.result end,
					order = 316
				},
				bidmaxheight = {
					type = "range",
					name = L["Bid result lines"],
					desc = L["Maximum number of lines before creating a scrollframe for bid results."],
					get = function() return MorgBid2.db.profile.bidheight end,
					set = function(info, v) MorgBid2.db.profile.bidheight = v end,
					min = 3, 
					max = 100, 
					step = 1,
					hidden = function() return not MorgBid2.db.profile.result end,
					order = 318
				},
				resultmaxheight = {
					type = "range",
					name = L["DKP list lines"],
					desc = L["Maximum number of lines before creating a scrollframe for dkplist."],
					get = function() return MorgBid2.db.profile.resultheight end,
					set = function(info, v) MorgBid2.db.profile.resultheight = v MorgBid2:UpdateResultMedia() end,
					min = 10, 
					max = 100, 
					step = 1,
					hidden = function() return not MorgBid2.db.profile.result end,
					order = 320
				},
				resultgrowth = {
			 		type = "select",
			 		name = L["Grow direction"],
			 		desc = L["Direction additional result frames should grow.  ie BOTTOM adds new frame under current one."],
			 		get = function() return MorgBid2.db.profile.resultgrow end,
			 		set = function(info, v) MorgBid2.db.profile.resultgrow = v MorgBid2_Options:SetGrow(v) end,
			 		values = GrowDirections, 
			 		hidden = function() return not MorgBid2.db.profile.result end,
					order = 330
				},
				resultfont = {
			 		type = "select",
			 		dialogControl = "LSM30_Font",
			 		name = L["Result Font"],
			 		get = function() return MorgBid2.db.profile.media.resultfont end,
			 		set = function(info, v) MorgBid2.db.profile.media.resultfont = v MorgBid2:UpdateResultMedia() end,
			 		values = AceGUIWidgetLSMlists.font, 
			 		hidden = function() return not MorgBid2.db.profile.result end,
					order = 340
				},
				resultfontsize = {
					type = "range",
					name = L["Result fontsize"],
					get = function() return MorgBid2.db.profile.media.resultfontsize end,
					set = function(info, v) MorgBid2.db.profile.media.resultfontsize = v MorgBid2:UpdateResultMedia() end,
					min = 1, 
					max = 30, 
					step = 1,
					hidden = function() return not MorgBid2.db.profile.result end,
					order = 350
				},
			}
		},
	}
}

function MorgBid2_Options:OnInitialize()
	if AddonLoader and AddonLoader.RemoveInterfaceOptions then
    		AddonLoader:RemoveInterfaceOptions("MorgBid2")
	end
	LibStub("AceConfig-3.0"):RegisterOptionsTable("MorgBid2", options)
	MorgBid2.optionsFrame = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("MorgBid2", "MorgBid2")
	options.args.profiles = LibStub("AceDBOptions-3.0"):GetOptionsTable(MorgBid2.db)
	MorgBid2.db.RegisterCallback(MorgBid2, "OnProfileChanged", "OnProfileChanged")
	MorgBid2.db.RegisterCallback(MorgBid2, "OnProfileCopied", "OnProfileChanged")
	MorgBid2.db.RegisterCallback(MorgBid2, "OnProfileReset", "OnProfileChanged")
end

function MorgBid2_Options:OnProfileChanged()
	db = MorgBid2.db.profile
end

function MorgBid2_Options:ResetFrames()
	db.point = "CENTER"
	db.relpoint = "CENTER"
	db.x = 0
	db.y = 0
	db.anchorpoint = "CENTER"
	db.anchorrelpoint = "CENTER"
	db.anchorx = 0
	db.anchory = 0
end

function MorgBid2_Options:SetColorOpt(info, r, g, b, a)
	local db = MorgBid2.db.profile.media
	local opt = info[#info]
	db[opt][1] = r
	db[opt][2] = g
	db[opt][3] = b
	db[opt][4] = a
	MorgBid2:UpdateFrameMedia()
end

function MorgBid2_Options:GetColorOpt(info)
	local opt = info[#info]
	return unpack(MorgBid2.db.profile.media[opt])
end

function MorgBid2_Options:SetGrow(v)
	local point, relpoint
	local dir = GrowDirections[v]
	if dir == "UP" then point, relpoint = "BOTTOMLEFT", "TOPLEFT"
	elseif dir == "DOWN" then point, relpoint = "TOPLEFT", "BOTTOMLEFT"
	elseif dir == "LEFT" then point, relpoint = "TOPRIGHT", "TOPLEFT"
	else point, relpoint = "TOPLEFT", "TOPRIGHT"
	end
	db.media.resultpoint, db.media.resultrelpoint = point, relpoint
end
